@@ -1,15 +1,17 @@
 import time
+import calendar
 import datetime
 import unittest
 import locale
 import sys
+from unittest import SkipTest
+from dateutil.tz import UTC
 
-from nose.plugins import skip
-from nose.tools import assert_raises
+import pytest
 from tests import utils
 
 from freezegun import freeze_time
-from freezegun.api import FakeDatetime, FakeDate, BaseFakeTime
+from freezegun.api import FakeDatetime, FakeDate
 
 try:
     import maya
@@ -17,6 +19,9 @@ try:
 except ImportError:
     maya = None
 
+# time.clock was removed in Python 3.8
+HAS_CLOCK = hasattr(time, 'clock')
+HAS_TIME_NS = hasattr(time, 'time_ns')
 
 class temp_locale(object):
     """Temporarily change the locale."""
@@ -33,7 +38,7 @@ class temp_locale(object):
             except locale.Error:
                 pass
         msg = 'could not set locale to any of: %s' % ', '.join(self.targets)
-        raise skip.SkipTest(msg)
+        raise SkipTest(msg)
 
     def __exit__(self, *args):
         locale.setlocale(locale.LC_ALL, self.old)
@@ -207,6 +212,8 @@ def test_time_gmtime():
         assert time_struct.tm_isdst == -1
 
 
+@pytest.mark.skipif(not HAS_CLOCK,
+                    reason="time.clock was removed in Python 3.8")
 def test_time_clock():
     with freeze_time('2012-01-14 03:21:34'):
         assert time.clock() == 0
@@ -253,6 +260,12 @@ def test_strftime():
             assert time.strftime("%Y") == "1970"
 
 
+def test_real_strftime_fall_through():
+    with freeze_time(ignore=['_pytest']):
+        time.strftime('%Y')
+        time.strftime('%Y', (2001, 1, 1, 1, 1, 1, 1, 1, 1)) == '2001'
+
+
 def test_date_object():
     frozen_date = datetime.date(year=2012, month=11, day=10)
     date_freezer = freeze_time(frozen_date)
@@ -316,12 +329,13 @@ def test_generator_object():
     with freeze_time(frozen_datetimes):
         assert datetime.datetime(2011, 1, 1) == datetime.datetime.now()
 
-    assert_raises(StopIteration, freeze_time, frozen_datetimes)
+    with pytest.raises(StopIteration):
+        freeze_time(frozen_datetimes)
 
 
 def test_maya_datetimes():
     if not maya:
-        raise skip.SkipTest("maya is optional since it's not supported for "
+        raise SkipTest("maya is optional since it's not supported for "
                             "enough python versions")
 
     with freeze_time(maya.when("October 2nd, 1997")):
@@ -392,12 +406,12 @@ class Tester(object):
 
     def test_class_decorator_skips_callable_object_py2(self):
         if sys.version_info[0] != 2:
-            raise skip.SkipTest("test target is Python2")
+            raise SkipTest("test target is Python2")
         assert self.a_mock.__class__ == Callable
 
     def test_class_decorator_wraps_callable_object_py3(self):
-        if sys.version_info[0] != 3:
-            raise skip.SkipTest("test target is Python3")
+        if sys.version_info[0] == 2:
+            raise SkipTest("test target is Python3+")
         assert self.a_mock.__wrapped__.__class__ == Callable
 
     @staticmethod
@@ -436,9 +450,7 @@ def test_nested_context_manager():
 def _assert_datetime_date_and_time_are_all_equal(expected_datetime):
     assert datetime.datetime.now() == expected_datetime
     assert datetime.date.today() == expected_datetime.date()
-    datetime_from_time = datetime.datetime.fromtimestamp(time.time())
-    timezone_adjusted_datetime = datetime_from_time + datetime.timedelta(seconds=time.timezone)
-    assert timezone_adjusted_datetime == expected_datetime
+    assert datetime.datetime.fromtimestamp(time.time()) == expected_datetime
 
 
 def test_nested_context_manager_with_tz_offsets():
@@ -629,16 +641,96 @@ def test_should_use_real_time():
     expected_frozen_gmt = (2015, 3, 5, 0, 0, 0, 3, 64, -1)
     expected_clock = 0
 
-    BaseFakeTime.call_stack_inspection_limit = 100  # just to increase coverage
+    from freezegun import api
+    api.call_stack_inspection_limit = 100  # just to increase coverage
+
+    timestamp_to_convert = 1579602312
+    time_tuple = time.gmtime(timestamp_to_convert)
 
     with freeze_time(frozen):
         assert time.time() == expected_frozen
         # assert time.localtime() == expected_frozen_local
         assert time.gmtime() == expected_frozen_gmt
-        assert time.clock() == expected_clock
+        if HAS_CLOCK:
+            assert time.clock() == expected_clock
+        if HAS_TIME_NS:
+            assert time.time_ns() == expected_frozen * 1e9
+
+        assert calendar.timegm(time.gmtime()) == expected_frozen
+        assert calendar.timegm(time_tuple) == timestamp_to_convert
 
     with freeze_time(frozen, ignore=['_pytest', 'nose']):
         assert time.time() != expected_frozen
         # assert time.localtime() != expected_frozen_local
         assert time.gmtime() != expected_frozen_gmt
-        assert time.clock() != expected_clock
+        if HAS_CLOCK:
+            assert time.clock() != expected_clock
+        if HAS_TIME_NS:
+            assert time.time_ns() != expected_frozen * 1e9
+
+        assert calendar.timegm(time.gmtime()) != expected_frozen
+        assert calendar.timegm(time_tuple) == timestamp_to_convert
+
+
+@pytest.mark.skipif(not HAS_TIME_NS,
+                    reason="time.time_ns is present only on 3.7 and above")
+def test_time_ns():
+    freezer = freeze_time("2012-01-14")
+    local_time = datetime.datetime(2012, 1, 14)
+    utc_time = local_time - datetime.timedelta(seconds=time.timezone)
+    expected_timestamp = time.mktime(utc_time.timetuple())
+
+    freezer.start()
+    assert time.time() == expected_timestamp
+    assert time.time_ns() == expected_timestamp * 1e9
+    freezer.stop()
+    assert time.time() != expected_timestamp
+    assert time.time_ns() != expected_timestamp * 1e9
+
+
+def test_compare_datetime_and_time_with_timezone(monkeypatch):
+    """
+    Compare the result of datetime.datetime.now() and time.time() in a non-UTC timezone. These
+    should be consistent.
+    """
+    try:
+        with monkeypatch.context() as m, freeze_time("1970-01-01 00:00:00"):
+            m.setenv("TZ", "Europe/Berlin")
+            time.tzset()
+
+            now = datetime.datetime.now()
+            assert now == datetime.datetime.fromtimestamp(time.time())
+            assert now == datetime.datetime.utcfromtimestamp(time.time())
+            assert now == datetime.datetime.utcnow()
+            assert now.timestamp() == time.time()
+    finally:
+        time.tzset()  # set the timezone back to what is was before
+
+
+def test_timestamp_with_tzoffset():
+    with freeze_time("2000-01-01", tz_offset=6):
+        utcnow = datetime.datetime(2000, 1, 1, 0)
+        nowtz = datetime.datetime(2000, 1, 1, 0, tzinfo=UTC)
+        now = datetime.datetime(2000, 1, 1, 6)
+        assert now == datetime.datetime.now()
+        assert now == datetime.datetime.fromtimestamp(time.time())
+        assert now.timestamp() == time.time()
+        assert nowtz.timestamp() == time.time()
+
+        assert utcnow == datetime.datetime.utcfromtimestamp(time.time())
+        assert utcnow == datetime.datetime.utcnow()
+
+@pytest.mark.skip("timezone handling is currently incorrect")
+def test_datetime_in_timezone(monkeypatch):
+    """
+    It is assumed that the argument passed to freeze_time is in UTC, unless explicitly indicated
+    otherwise. Therefore datetime.now() should return the frozen time with an offset.
+    """
+    try:
+        with monkeypatch.context() as m, freeze_time("1970-01-01 00:00:00"):
+            m.setenv("TZ", "Europe/Berlin")
+            time.tzset()
+
+            assert datetime.datetime.now() == datetime.datetime(1970, 1, 1, 1, 0, 0)
+    finally:
+        time.tzset()  # set the timezone back to what is was before
